@@ -225,6 +225,7 @@ unenroll = Metric(
     description=dedent("""\
         Counts the number of clients with an experiment unenrollment event.
     """),
+    bigger_is_better=False,
 )
 
 #: Metric: ...
@@ -299,3 +300,13 @@ pocket_click_count = Metric(
         Counts the number of pocket tile clicks made by each client.
     """),
 )
+
+
+#: Metric: ...
+days_of_use = Metric(
+    name="days_of_use",
+    data_source=clients_daily,
+    select_expr="COUNT(*)",
+    friendly_name="Days of use",
+    description="The number of days in the interval that each client sent a main ping."
+)
